@@ -1,7 +1,7 @@
 use astra::{Body, Response, Server};
 
 fn main() {
-    Server::bind("localhost:3000")
+    Server::bind("127.0.0.1:3000")
         .serve(|_req| Response::new(Body::new("Hello World!")))
         .expect("serve failed");
 }
